# Flytekit Snowflake Plugin

Snowflake enables us to build data-intensive applications without operational burden. Flyte backend can be connected with the Snowflake service. Once enabled, it can allow you to query a Snowflake service.

To install the plugin, run the following command:

```bash
pip install flytekitplugins-snowflake
```

To configure Snowflake in the Flyte deployment's backend, follow the [configuration guide](https://docs.flyte.org/projects/cookbook/en/latest/auto/integrations/external_services/snowflake/index.html#configuring-the-backend-to-get-snowflake-working).

An [example](https://docs.flyte.org/projects/cookbook/en/latest/auto/integrations/external_services/snowflake/snowflake.html#sphx-glr-auto-integrations-external-services-snowflake-snowflake-py) showcasing Snowflake service can be found in the documentation.
